@@ -56,6 +56,20 @@ class MyPaintApp(App):
     def build(self):
         return MyPaintWidget()
 
+    def on_stop(self):
+        global last_stroke
+        Logger.info('App closed')
+        recording.append(last_stroke)
+        last_stroke = []
+        raw_data_json = json.dumps(recording)
+        logging.info(recording)
+        logging.info("Start evaluation...")
+        # TODO: use args.verbose instead of True if possible
+        # args.model,
+        results = utils.classify_single_recording(raw_data_json,
+                                                  utils.default_model(),
+                                                  True)
+        show_results(results)
 
 # def get_parser():
 #     from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
@@ -78,22 +92,7 @@ class MyPaintApp(App):
 #     return parser
 
 
-if __name__ == '__main__':
-    print("Start recording.")
-    #args = get_parser().parse_args()
-    MyPaintApp().run()
-    recording.append(last_stroke)
-    last_stroke = []
-    raw_data_json = json.dumps(recording)
-    logging.info(recording)
-    logging.info("Start evaluation...")
-    # TODO: use args.verbose instead of True if possible
-    # args.model,
-    results = utils.classify_single_recording(raw_data_json,
-                                              utils.default_model(),
-                                              True)
-    n = 10  # args.n
-
+def show_results(results, n=10):  # args.n
     # Print headline
     print("{0:18s} {1:5s}".format("LaTeX Code", "Prob"))
     print("#"*50)
@@ -104,3 +103,9 @@ if __name__ == '__main__':
             n -= 1
         print("{0:18s} {1:5f}".format(latex, probability))
     print("#"*50)
+
+
+if __name__ == '__main__':
+    print("Start recording.")
+    #args = get_parser().parse_args()
+    MyPaintApp().run()
